@@ -239,16 +239,30 @@ BasePlotCompositeWidget::createMainMenu()
 
   mp_mainMenu->addSeparator();
 
-  QAction *save_plot_to_clipboard_p =
-    new QAction("Save plot &graphics to clipboard", this);
-  save_plot_to_clipboard_p->setStatusTip(tr("Save plot to clipboard"));
-  save_plot_to_clipboard_p->setShortcut(QKeySequence("Ctrl+G, C"));
+  mp_plotGraphicsMenu = new QMenu("Save plot graphics to clipboard");
 
-  connect(save_plot_to_clipboard_p, &QAction::triggered, [this]() {
-    savePlotGraphicsToClipboard();
+  QAction *save_svg_plot_to_clipboard_p =
+    new QAction("Save SVG plot graphics", this);
+  save_svg_plot_to_clipboard_p->setStatusTip(tr("Save SVG plot graphics"));
+
+  mp_plotGraphicsMenu->addAction(save_svg_plot_to_clipboard_p);
+
+  connect(save_svg_plot_to_clipboard_p, &QAction::triggered, [this]() {
+    saveSvgPlotToClipboard();
   });
 
-  mp_mainMenu->addAction(save_plot_to_clipboard_p);
+  QAction *save_raster_plot_to_clipboard_p =
+    new QAction("Save RASTER plot graphics", this);
+  save_raster_plot_to_clipboard_p->setStatusTip(
+    tr("Save RASTER plot graphics"));
+
+  mp_plotGraphicsMenu->addAction(save_raster_plot_to_clipboard_p);
+
+  connect(save_raster_plot_to_clipboard_p, &QAction::triggered, [this]() {
+    saveRasterPlotToClipboard();
+  });
+
+  mp_mainMenu->addMenu(mp_plotGraphicsMenu);
 
   // qDebug() << "EXIT";
 }
@@ -324,19 +338,114 @@ BasePlotCompositeWidget::savePlotToPdfFile(const QString &file_name,
 }
 
 
+std::pair<int, int>
+BasePlotCompositeWidget::computePlotSize(std::pair<int, int> requested,
+                                         std::pair<int, int> actual) const
+{
+  int actual_width  = actual.first;
+  int actual_height = actual.second;
+
+  int requested_width  = requested.first;
+  int requested_height = requested.second;
+
+  int final_width;
+  int final_height;
+
+  double aspect_ratio = actual_width / actual_height;
+
+  // qDebug() << "aspect_ratio:" << aspect_ratio;
+
+  if(!requested_width && !requested_height)
+    {
+      // The user has requested no dimensions. Use the actual plot size.
+      // qDebug() << "Both dimensions are naught.";
+      final_width  = actual_width;
+      final_height = actual_height;
+    }
+  else if(!requested_width)
+    {
+      // Compute this dimension using the aspect ratio.
+
+      // qDebug() << "width is naught.";
+      final_height = requested_height;
+      final_width  = final_height * aspect_ratio;
+    }
+  else if(!requested_height)
+    {
+      // Compute this dimension using the aspect ratio.
+      // qDebug() << "height is naught.";
+      final_width  = requested_width;
+      final_height = final_width / aspect_ratio;
+    }
+  else
+    {
+      // qDebug() << "Both dimensions are non-naught.";
+      final_width  = requested_width;
+      final_height = requested_height;
+    }
+
+  // qDebug() << "Saving PNG file with final dimensions:"
+  //<< final_width << final_height;
+
+  return std::pair<int,int>(final_width, final_height);
+}
+
+
 bool
 BasePlotCompositeWidget::savePlotToSvgFile(const QString &file_name)
 {
   QSize plot_widget_size = mp_plotWidget->size();
 
-  QSvgGenerator svggenerator;
-  svggenerator.setFileName(file_name);
+  QSvgGenerator svg_generator;
+  svg_generator.setFileName(file_name);
   QCPPainter qcpPainter;
-  qcpPainter.begin(&svggenerator);
+  qcpPainter.begin(&svg_generator);
   mp_plotWidget->toPainter(
     &qcpPainter, plot_widget_size.width(), plot_widget_size.height());
   qcpPainter.end();
 
+  // How about reading the full filel into a string and then setting that string
+  // to the clipboard as an image.
+
+  QBuffer out_buffer;
+  out_buffer.open(QBuffer::WriteOnly);
+  svg_generator.setOutputDevice(&out_buffer);
+
+  qcpPainter.begin(&svg_generator);
+  mp_plotWidget->toPainter(
+    &qcpPainter, plot_widget_size.width(), plot_widget_size.height());
+  qcpPainter.end();
+
+  qDebug() << "out_buffer size:" << out_buffer.size();
+
+  QMimeData *mime_data_p = new QMimeData();
+  mime_data_p->setData("image/svg+xml", out_buffer.buffer());
+  QApplication::clipboard()->setMimeData(mime_data_p, QClipboard::Clipboard);
+
+  return true;
+}
+
+
+bool
+BasePlotCompositeWidget::saveSvgPlotToClipboard()
+{
+  QSize plot_widget_size = mp_plotWidget->size();
+
+  QBuffer out_buffer;
+  out_buffer.open(QBuffer::WriteOnly);
+  QSvgGenerator svg_generator;
+  svg_generator.setOutputDevice(&out_buffer);
+
+  QCPPainter qcpPainter;
+  qcpPainter.begin(&svg_generator);
+  mp_plotWidget->toPainter(
+    &qcpPainter, plot_widget_size.width(), plot_widget_size.height());
+  qcpPainter.end();
+
+  QMimeData *mime_data_p = new QMimeData();
+  mime_data_p->setData("image/svg+xml", out_buffer.buffer());
+  QApplication::clipboard()->setMimeData(mime_data_p, QClipboard::Clipboard);
+
   return true;
 }
 
@@ -345,7 +454,19 @@ bool
 BasePlotCompositeWidget::savePlotToPngFile(
   const QString &file_name, int width, int height, int scale, int quality) const
 {
-  return mp_plotWidget->savePng(file_name, width, height, scale, quality);
+  // qDebug() << "Saving PNG file with:" << width << height << scale;
+
+  QSize plot_widget_size = mp_plotWidget->size();
+
+  std::pair<int, int> plot_dimensions = computePlotSize(
+    std::pair<int, int>(width, height),
+    std::pair<int, int>(plot_widget_size.width(), plot_widget_size.height()));
+
+   //qDebug() << "Saving PNG file with final dimensions:"
+  //<< plot_dimensions.first << plot_dimensions.second;
+
+  return mp_plotWidget->savePng(
+    file_name, plot_dimensions.first, plot_dimensions.second, scale, quality);
 }
 
 
@@ -353,34 +474,29 @@ bool
 BasePlotCompositeWidget::savePlotToJpgFile(
   const QString &file_name, int width, int height, int scale, int quality) const
 {
-  return mp_plotWidget->saveJpg(file_name, width, height, scale, quality);
+  // qDebug() << "Saving JPG file with:" << width << height << scale;
+
+  QSize plot_widget_size = mp_plotWidget->size();
+
+  std::pair<int, int> plot_dimensions = computePlotSize(
+    std::pair<int, int>(width, height),
+    std::pair<int, int>(plot_widget_size.width(), plot_widget_size.height()));
+
+   //qDebug() << "Saving JPG file with final dimensions:"
+  //<< plot_dimensions.first << plot_dimensions.second;
+
+  return mp_plotWidget->saveJpg(
+    file_name, plot_dimensions.first, plot_dimensions.second, scale, quality);
 }
 
 
 bool
-BasePlotCompositeWidget::savePlotGraphicsToClipboard()
+BasePlotCompositeWidget::saveRasterPlotToClipboard()
 {
   QSize plot_widget_size = mp_plotWidget->size();
 
-  QSvgGenerator svggenerator;
-  svggenerator.setFileName("/tmp/svg-rendering.svg");
-  QCPPainter qcpPainter;
-  qcpPainter.begin(&svggenerator);
-  mp_plotWidget->toPainter(&qcpPainter, 400);
-  qcpPainter.end();
-
-
-  return savePlotGraphicsToClipboard(
+  QPixmap pixmap = mp_plotWidget->toPixmap(
     plot_widget_size.width(), plot_widget_size.height(), 1);
-}
-
-
-bool
-BasePlotCompositeWidget::savePlotGraphicsToClipboard(int width,
-                                                     int height,
-                                                     int scale)
-{
-  QPixmap pixmap = mp_plotWidget->toPixmap(width, height, scale);
 
   QClipboard *clipboard_p = QApplication::clipboard();
   clipboard_p->setPixmap(pixmap);
@@ -534,7 +650,15 @@ BasePlotCompositeWidget::xAxisMeasurement(
   context.m_selectionPolygon.rangeX(start, end);
   double delta = abs(end - start);
   int decimals = pappso::Utils::zeroDecimalsInValue(delta) + 3;
-  text += QString(" -- xDelta: %1").arg(end - start, 0, 'f', decimals);
+  text += QString(" -- xDelta: %1").arg(delta, 0, 'f', decimals);
+
+  if(delta < 1)
+    {
+      // And also the inverse of xDelta because it provides a hint to the charge
+      // is the xDelta is between to consecutive peaks of an isotopic cluster.
+
+      text += QString(" -- 1/xDelta: %1").arg(1 / delta, 0, 'f', decimals);
+    }
 
   // We want the Y delta only if the polygon is 2D.
   if(context.m_selectionPolygon.is2D() && with_delta)
@@ -1031,17 +1155,17 @@ BasePlotCompositeWidget::getMzIntegrationParams(
         }
       else
         {
-          //qDebug().noquote() << "Got the most recent mz integration params:"
-                             //<< most_recent_mz_integration_params_p->toString();
+          // qDebug().noquote() << "Got the most recent mz integration params:"
+          //<< most_recent_mz_integration_params_p->toString();
 
           mz_integration_params = *most_recent_mz_integration_params_p;
         }
     }
-  //else
-    //{
-      //qDebug().noquote() << "Got the default mz integration params:"
-                         //<< mz_integration_params.toString();
-    //}
+  // else
+  //{
+  // qDebug().noquote() << "Got the default mz integration params:"
+  //<< mz_integration_params.toString();
+  //}
 
   if(!mz_integration_params.isValid())
     qFatal("Cannot be possible not to have valid mz integration parameters.");
