@@ -46,6 +46,11 @@
 /////////////////////// QCustomPlot
 
 
+/////////////////////// libmass includes
+#include <libmass/PeakCentroid.hpp>
+#include <libmass/MassDataCborMassSpectrumHandler.hpp>
+
+
 /////////////////////// pappsomspp includes
 #include <pappsomspp/widget/plotwidget/massspectraceplotwidget.h>
 #include <pappsomspp/processing/combiners/tracepluscombiner.h>
@@ -60,8 +65,8 @@
 #include "MassSpecTracePlotWidget.hpp"
 #include "MassSpecTracePlotWnd.hpp"
 #include "ProgramWindow.hpp"
-#include "../nongui/MassPeakShaperConfig.hpp"
-#include "../nongui/MassPeakShaper.hpp"
+#include <libmass/MassPeakShaperConfig.hpp>
+#include <libmass/MassPeakShaper.hpp>
 #include "ColorSelector.hpp"
 
 
@@ -347,10 +352,15 @@ MassSpecTracePlotCompositeWidget::gaussianFitOnVisibleMaxima()
   double *y     = new double[N];
   double *log_y = new double[N];
 
+  pappso::DataPoint most_intense_datapoint;
+
   for(size_t iter = 0; iter < local_maxima_trace.size(); ++iter)
     {
       pappso::DataPoint data_point = local_maxima_trace.at(iter);
 
+      if(data_point.y > most_intense_datapoint.y)
+        most_intense_datapoint = data_point;
+
       x[iter] = data_point.x;
       y[iter] = data_point.y;
 
@@ -500,14 +510,65 @@ MassSpecTracePlotCompositeWidget::gaussianFitOnVisibleMaxima()
 
   // At this point use our facility to compute the Gaussian trace.
 
-  MassPeakShaperConfig mass_peak_shaper_config(
-    0, fwhm, "H", 1, 500, 0, 1, MassPeakShapeType::GAUSSIAN);
-  MassPeakShaper mass_peak_shaper(gaussian_mu, A, mass_peak_shaper_config);
+  // This was the old version.
+  // libmass::MassPeakShaperConfig mass_peak_shaper_config(
+  // 0, fwhm, "H", 1, 500, 0, 1, libmass::MassPeakShapeType::GAUSSIAN);
+
+  libmass::MassPeakShaperConfig mass_peak_shaper_config;
+  mass_peak_shaper_config.setResolution(0);
+  mass_peak_shaper_config.setFwhm(fwhm);
+  mass_peak_shaper_config.setIonizationFormula("H");
+  mass_peak_shaper_config.setPointCount(200);
+  mass_peak_shaper_config.setReferencePeakMz(most_intense_datapoint.x);
+  mass_peak_shaper_config.setMzStep(0);
+  mass_peak_shaper_config.setNormFactor(1);
+  mass_peak_shaper_config.setMassPeakShapeType(
+    libmass::MassPeakShapeType::GAUSSIAN);
+
+  libmass::MassPeakShaper mass_peak_shaper(
+    gaussian_mu, A, mass_peak_shaper_config);
 
   mass_peak_shaper.computePeakShape();
 
   pappso::Trace fit_trace = mass_peak_shaper.getTrace();
 
+#if 0
+
+  // Testbed for the CBOR classes and the QTcpSocket communications.
+
+  // qDebug() << "Going to write this trace:" << fit_trace.toString();
+
+  libmass::MassDataCborMassSpectrumHandler cbor_handler(this, fit_trace);
+
+  QByteArray byte_array;
+
+  cbor_handler.writeByteArray(byte_array);
+
+  qDebug()
+    << "Written the Gaussian mass spectrum to a byte array that is now of size:"
+    << byte_array.size();
+
+  qDebug() << "Going to signal that the byte array has to be served.";
+  getParentWnd()->massDataToBeServedSignal(byte_array);
+  qDebug() << "Signalled that the byte array has to be served.";
+
+
+  // And now read it back from file.
+  // cbor_trace_handler.clearTrace();
+  // cbor_trace_handler.setInputFileName("/tmp/prova.cbor");
+  // cbor_trace_handler.readFile();
+
+  // pappso::Trace read_trace = cbor_trace_handler.getTrace();
+
+  // qDebug() << "Read back this trace:" << read_trace.toString()
+  //<< "of mass data type:"
+  //<< static_cast<quint64>(cbor_trace_handler.getMassDataType())
+  //<< "with title:" << cbor_trace_handler.getTitle();
+
+  // QClipboard *clipboard = QApplication::clipboard();
+  // clipboard->setText(read_trace.toString());
+
+#endif 
 
 #if 0
 
@@ -679,11 +740,11 @@ MassSpecTracePlotCompositeWidget::mainMenuPushButtonClicked()
 {
   // qDebug() << "ENTER";
 
-  //// Create the contextual menu that will show when the button is clicked (see
-  //// below).
+  //// Create the contextual menu that will show when the button is
+  /// clicked (see / below).
 
-  // The menu, when it is opened (shown) changes the size of the plot widget. We
-  // want to restore the initial size.
+  // The menu, when it is opened (shown) changes the size of the plot
+  // widget. We want to restore the initial size.
 
   QByteArray composite_plot_widget_geometry = mp_plotWidget->saveGeometry();
 
@@ -700,10 +761,11 @@ void
 MassSpecTracePlotCompositeWidget::plotWidgetKeyPressEvent(
   const pappso::MassSpecTracePlotContext &context)
 {
-  //qDebug().noquote() << "ENTER with massplotcontext:" << context.toString();
+  // qDebug().noquote() << "ENTER with massplotcontext:" <<
+  // context.toString();
 
-  // First call the base class that will fill-in the generic fields if the space
-  // char was pressed.
+  // First call the base class that will fill-in the generic fields if the
+  // space char was pressed.
   BaseTracePlotCompositeWidget::plotWidgetKeyPressEvent(context);
 
   // qDebug() << "After filling-in by base class, the stanza is:"
@@ -744,7 +806,7 @@ MassSpecTracePlotCompositeWidget::plotWidgetKeyPressEvent(
 
       QString stanza = craftAnalysisStanza(context);
 
-      //qDebug() << "analysis stanza:" << stanza;
+      // qDebug() << "analysis stanza:" << stanza;
 
       // At this point, the analysis stanza can be effectively recorded.
 
@@ -754,13 +816,13 @@ MassSpecTracePlotCompositeWidget::plotWidgetKeyPressEvent(
   // if(context.m_pressedKeyCode == Qt::Key_Space)
   else if(context.m_pressedKeyCode == Qt::Key_M)
     {
-      // The M (lowercase) keyboard key triggers copying the m/z value to the
-      // clipboard when a deconvolution was performed.
+      // The M (lowercase) keyboard key triggers copying the m/z value to
+      // the clipboard when a deconvolution was performed.
 
       QString mz_value_as_string =
         QString("%1").arg(context.m_lastMr, 0, 'f', 6);
 
-      //qDebug() << "The mz_value_as_string:" << mz_value_as_string;
+      // qDebug() << "The mz_value_as_string:" << mz_value_as_string;
 
       QClipboard *clipboard_p = QApplication::clipboard();
       clipboard_p->setText(mz_value_as_string, QClipboard::Clipboard);
@@ -769,12 +831,12 @@ MassSpecTracePlotCompositeWidget::plotWidgetKeyPressEvent(
   // else if(context.m_pressedKeyCode == Qt::Key_M)
   else if(context.m_pressedKeyCode == Qt::Key_Z)
     {
-      // The Z (lowercase) keyboard key triggers copying the z value to the
-      // clipboard when a deconvolution was performed.
+      // The Z (lowercase) keyboard key triggers copying the z value to
+      // the clipboard when a deconvolution was performed.
 
       QString z_value_as_string = QString("%1").arg(context.m_lastZ);
 
-      //qDebug() << "The z_value_as_string:" << z_value_as_string;
+      // qDebug() << "The z_value_as_string:" << z_value_as_string;
 
       QClipboard *clipboard_p = QApplication::clipboard();
       clipboard_p->setText(z_value_as_string, QClipboard::Clipboard);
@@ -783,16 +845,16 @@ MassSpecTracePlotCompositeWidget::plotWidgetKeyPressEvent(
   // else if(context.m_pressedKeyCode == Qt::Key_Z)
   else if(context.m_pressedKeyCode == Qt::Key_X)
     {
-      // The X (lowercase) keyboard key triggers copying the m/z value exactly
-      // as the last cursor position (no deconvolution needs to be performed to
-      // get to the x value (in a mass spectrum trace, the x value is the m/z
-      // value).
+      // The X (lowercase) keyboard key triggers copying the m/z value
+      // exactly as the last cursor position (no deconvolution needs to be
+      // performed to get to the x value (in a mass spectrum trace, the x
+      // value is the m/z value).
 
       QPointF point = context.m_lastCursorHoveredPoint;
 
       QString x_value_as_string = QString("%1").arg(point.x(), 0, 'f', 6);
 
-      //qDebug() << "The x_value_as_string:" << x_value_as_string;
+      // qDebug() << "The x_value_as_string:" << x_value_as_string;
 
       QClipboard *clipboard_p = QApplication::clipboard();
       clipboard_p->setText(x_value_as_string, QClipboard::Clipboard);
@@ -808,8 +870,8 @@ MassSpecTracePlotCompositeWidget::plotWidgetKeyReleaseEvent(
 {
   BaseTracePlotCompositeWidget::plotWidgetKeyReleaseEvent(context);
 
-  // The release event sets the local key code to 0 so that we know that no
-  // keyboard key is being pressed *now*.
+  // The release event sets the local key code to 0 so that we know that
+  // no keyboard key is being pressed *now*.
   m_plotWidgetPressedKeyCode = context.m_pressedKeyCode;
 
   // qDebug() << "The key:" << m_plotWidgetPressedKeyCode
@@ -824,31 +886,29 @@ MassSpecTracePlotCompositeWidget::plotWidgetMassDeconvolution(
   // qDebug();
 
   // The point with the append strategy below is that sometimes they get
-  // chained ad infinitum if the mouse movements allow calculating spurious
-  // deconvolutions...
-  // We want to append the deconvolution results to the status text.
-  // QString new_text =
+  // chained ad infinitum if the mouse movements allow calculating
+  // spurious deconvolutions... We want to append the deconvolution
+  // results to the status text. QString new_text =
   // m_ui.statusLineEdit->text() + QString("-- z: %1 - m/z: %2 - Mr: %3")
   //.arg(context.m_lastZ)
   //.arg(context.m_lastMz)
   //.arg(context.m_lastMr);
 
-  QString new_text =
-    QString("[%1--%2] - delta: %3 -- z: %4 - m/z: %5 - Mr: %6")
-      .arg(std::min<double>(context.m_xRegionRangeStart,
-                            context.m_xRegionRangeEnd),
-           0,
-           'f',
-           4)
-      .arg(std::max<double>(context.m_xRegionRangeStart,
-                            context.m_xRegionRangeEnd),
-           0,
-           'f',
-           4)
-      .arg(fabs(context.m_xDelta), 0, 'f', 4)
-      .arg(context.m_lastZ)
-      .arg(context.m_lastMz, 0, 'f', 4)
-      .arg(context.m_lastMr, 0, 'f', 3);
+  QString new_text = QString("[%1--%2] - delta: %3 -- z: %4 - m/z: %5 - Mr: %6")
+                       .arg(std::min<double>(context.m_xRegionRangeStart,
+                                             context.m_xRegionRangeEnd),
+                            0,
+                            'f',
+                            4)
+                       .arg(std::max<double>(context.m_xRegionRangeStart,
+                                             context.m_xRegionRangeEnd),
+                            0,
+                            'f',
+                            4)
+                       .arg(fabs(context.m_xDelta), 0, 'f', 4)
+                       .arg(context.m_lastZ)
+                       .arg(context.m_lastMz, 0, 'f', 4)
+                       .arg(context.m_lastMr, 0, 'f', 3);
 
   m_ui.statusLineEdit->setText(new_text);
 }
@@ -884,8 +944,8 @@ MassSpecTracePlotCompositeWidget::moveMouseCursorToNextGraphPoint(
 {
   BaseTracePlotCompositeWidget::moveMouseCursorToNextGraphPoint(context);
 
-  // Modify the context to conform to the integration range that was computed
-  // in the base class function.
+  // Modify the context to conform to the integration range that was
+  // computed in the base class function.
 
   pappso::BasePlotContext local_context = context;
   local_context.m_xRegionRangeStart     = m_integrationRange.lower;
@@ -902,17 +962,18 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
 {
   // qDebug().noquote() << "context:" << context.toString();
 
-  // The reference implementation is the TicXicChromTracePlotCompositeWidget
-  // one. Look there for all the explanative comments.
+  // The reference implementation is the
+  // TicXicChromTracePlotCompositeWidget one. Look there for all the
+  // explanative comments.
 
   // Make a local copy of the context because we may need to modify it.
   pappso::BasePlotContext local_context = context;
 
-  // Check if the selection polygon contain meaningful data. We are in trace
-  // plot widget, so the selection polygon might be in the form of a
-  // mono-dimensional polygon, although this is not mandatory. But we rely on
-  // the selection polygon to be of 1 or 2 dimension for some optimizations. So,
-  // if the polygon is 2D, convert it to 1D.
+  // Check if the selection polygon contain meaningful data. We are in
+  // trace plot widget, so the selection polygon might be in the form of a
+  // mono-dimensional polygon, although this is not mandatory. But we rely
+  // on the selection polygon to be of 1 or 2 dimension for some
+  // optimizations. So, if the polygon is 2D, convert it to 1D.
 
   if(local_context.m_selectionPolygon.is2D())
     qDebug() << "Odd situation where the selection polygon is two-dimensional "
@@ -923,8 +984,8 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
 
   // Sanity check.
 
-  // The user may select at the left of the x=0, but that does not make sense if
-  // the whole selected region is in the x axis negative space.
+  // The user may select at the left of the x=0, but that does not make
+  // sense if the whole selected region is in the x axis negative space.
   double range_start;
   double range_end;
 
@@ -950,8 +1011,9 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
       return;
     }
 
-  // Create a local copy of the processing flow so that we can modify it by
-  // adding the new processing step that describes what we are doing now.
+  // Create a local copy of the processing flow so that we can modify it
+  // by adding the new processing step that describes what we are doing
+  // now.
 
   ProcessingFlow local_processing_flow =
     getProcessingFlowForPlottable(plottable_p);
@@ -964,7 +1026,8 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
 
   // qDebug() << ms_run_data_set_csp->getMsRunDataSetStats().toString();
 
-  // Create a processing step to document the specifics of this new integration.
+  // Create a processing step to document the specifics of this new
+  // integration.
 
   ProcessingStep *processing_step_p = new ProcessingStep();
 
@@ -974,15 +1037,17 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
   // Only set the ms frag spec to the processing spec if it is valid.
   if(ms_fragmentation_spec.isValid())
     {
-      // qDebug().noquote() << "The default ms frag spec from the processing
-      // flow " "is valid, using it : "
+      // qDebug().noquote() << "The default ms frag spec from the
+      // processing flow " "is valid, using it : "
       //<< ms_fragmentation_spec.toString();
 
       processing_step_p->setMsFragmentationSpec(ms_fragmentation_spec);
     }
   else
     {
-      // qDebug() << "The default ms frag spec from the processing flow is not "
+      // qDebug() << "The default ms frag spec from the processing flow is
+      // not
+      // "
       //"valid. Not using it.";
     }
 
@@ -994,8 +1059,8 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
   // We must say what is the data source processing type.
   processing_step_p->setSrcProcessingType(pappso::Axis::x, "MZ");
 
-  // It is essential that we document the relation between the axes and the
-  // corresponding data type.
+  // It is essential that we document the relation between the axes and
+  // the corresponding data type.
   processing_step_p->setDataKind(pappso::Axis::x, pappso::DataKind::mz);
   processing_step_p->setDataKind(pappso::Axis::y, pappso::DataKind::unset);
 
@@ -1033,20 +1098,22 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
       // At this point we need to define how the mass data integrator will
       // combine spectra, since we are integrating to a mass spectrum.
 
-      // This is a multi-layer work: the graph has a ProcessingFlow associated
-      // to it via the m_graphProcessingFlowMap. We have gotten it above.
+      // This is a multi-layer work: the graph has a ProcessingFlow
+      // associated to it via the m_graphProcessingFlowMap. We have gotten
+      // it above.
 
       // Extract from it the default pappso::MzIntegrationParams:
 
       pappso::MzIntegrationParams mz_integration_params =
         local_processing_flow.getDefaultMzIntegrationParams();
 
-      // If it is not valid, then try mz integration params from the various
-      // steps of the flow. Preferentially the most recent ones.
+      // If it is not valid, then try mz integration params from the
+      // various steps of the flow. Preferentially the most recent ones.
       if(!mz_integration_params.isValid())
         {
           // qDebug()
-          //<< "The processing flow's default mz integ params are not valid.";
+          //<< "The processing flow's default mz integ params are not
+          // valid.";
 
           const pappso::MzIntegrationParams *mz_integration_params_p =
             local_processing_flow.mostRecentMzIntegrationParams();
@@ -1056,8 +1123,8 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
         }
 
       // If it is not valid, finally resort to the parameters that can be
-      // crafted on the basis of the statistical analysis of the ms run data
-      // set while it was loaded from file.
+      // crafted on the basis of the statistical analysis of the ms run
+      // data set while it was loaded from file.
       if(!mz_integration_params.isValid())
         {
           // qDebug() << "The most recent mz integ param are not valid.";
@@ -1177,30 +1244,32 @@ MassSpecTracePlotCompositeWidget::addTrace(
 
   QColor local_color(color);
 
-  // Get color from the available colors, or if none is available, create one
-  // randomly without requesting the user to select one from QColorDialog.
+  // Get color from the available colors, or if none is available, create
+  // one randomly without requesting the user to select one from
+  // QColorDialog.
   if(!local_color.isValid())
-    local_color = ColorSelector::getColor(true);
+    local_color = libmassgui::ColorSelector::getColor(true);
 
-  // qDebug().noquote() << "The processing flow:" << processing_flow.toString();
+  // qDebug().noquote() << "The processing flow:" <<
+  // processing_flow.toString();
 
-  // The QCPGraph that is going to be created will have the proper color defined
-  // in it. Also, we grab the graph that has been created because we need to
-  // associate it with the matching processing flow in the map.
+  // The QCPGraph that is going to be created will have the proper color
+  // defined in it. Also, we grab the graph that has been created because
+  // we need to associate it with the matching processing flow in the map.
 
-  // We have to verify if there is a destination policy for this composite plot
-  // widget. There are different situations.
+  // We have to verify if there is a destination policy for this composite
+  // plot widget. There are different situations.
 
-  // 1. THe erase trace and create new push button is checked: the user want to
-  // remove all the selected traces and replace them with the trace passed as
-  // parameter.
+  // 1. THe erase trace and create new push button is checked: the user
+  // want to remove all the selected traces and replace them with the
+  // trace passed as parameter.
 
-  // 2. The keep traces and combine push button is checked: the user want to
-  // combine all the selected traces individually to the new trace passed as
-  // parameters.
+  // 2. The keep traces and combine push button is checked: the user want
+  // to combine all the selected traces individually to the new trace
+  // passed as parameters.
 
-  // 3. If no destination policy is defined, simply add the new trace without
-  // touching any other trace that might be already plotted there.
+  // 3. If no destination policy is defined, simply add the new trace
+  // without touching any other trace that might be already plotted there.
 
   // We'll need this to factorize code.
   bool must_create_new_graph        = false;
@@ -1224,10 +1293,11 @@ MassSpecTracePlotCompositeWidget::addTrace(
 
       // Combination is requested. There are some situations:
 
-      // 1. If there is no single trace in the widget, then simply add a new
-      // trace.
+      // 1. If there is no single trace in the widget, then simply add a
+      // new trace.
       //
-      // 2. If there is a single trace, then combine with that, selected or not.
+      // 2. If there is a single trace, then combine with that, selected
+      // or not.
       //
       // 3. If there are multiple traces, then only combine with those.
 
@@ -1242,15 +1312,15 @@ MassSpecTracePlotCompositeWidget::addTrace(
         {
           // qDebug() << "Adding new trace with combination requested.";
 
-          // Since we are asked that an integration to a mass spectrum be
-          // performed, there must be a non-nullptr mz integration pointer in
-          // the step.
+          // Since we are asked that a combination to a mass spectrum be
+          // performed, there must be a non-nullptr mz integration pointer
+          // in the step.
           const pappso::MzIntegrationParams *mz_integration_params_p =
             processing_flow.mostRecentMzIntegrationParams();
 
           if(mz_integration_params_p == nullptr)
             qFatal(
-              "Integrating to a mass spectrum, cannot be that the mz "
+              "Combining to a mass spectrum, cannot be that the mz "
               "integration "
               "params are not available in the processing flow.");
 
@@ -1275,8 +1345,8 @@ MassSpecTracePlotCompositeWidget::addTrace(
                     static_cast<pappso::BaseTracePlotWidget *>(mp_plotWidget)
                       ->toTrace(static_cast<QCPGraph *>(iter_plottable_p));
 
-                  // Initialize the receiving map trace with the trace we are
-                  // iterating into.
+                  // Initialize the receiving map trace with the trace we
+                  // are iterating into.
                   pappso::MapTrace map_trace(iter_trace);
 
                   // And now combine the trace we got as parameter.
@@ -1301,15 +1371,16 @@ MassSpecTracePlotCompositeWidget::addTrace(
                   QVector<double> value_vector;
 
                   // Apparently, as of 20210928, that bug is fixed.
-                  //#pragma GCC warning "Filippo Rusconi: Please check if the
+                  //#pragma GCC warning "Filippo Rusconi: Please check if
+                  // the
                   // bug was fixed in Qt"
 
                   // Now replace the graph's data. Note that the data are
                   // inherently sorted (true below).
 
-                  // The begin() -- end() ranges constructor did not work as of
-                  // Qt 5.14.2 this day: 20200721 -- and still does not work
-                  // 20211018.
+                  // The begin() -- end() ranges constructor did not work
+                  // as of Qt 5.14.2 this day: 20200721 -- and still does
+                  // not work 20211018.
 
                   // key_vector   = QVector(map_trace.xValues().begin(),
                   // map_trace.xValues().end());
@@ -1334,28 +1405,32 @@ MassSpecTracePlotCompositeWidget::addTrace(
               pappso::MassSpectrumMinusCombiner mass_spectrum_minus_combiner;
               pappso::MassSpectrumPlusCombiner mass_spectrum_plus_combiner;
 
-              // There is a requirement to perform a binning. We thus need to
-              // create the bins. The smallest mz step needs to be the smallest
-              // of the trace we get as a parameter and of the trace we got for
-              // the receiving graph.
+              // There is a requirement to perform a binning. We thus need
+              // to create the bins. The smallest mz step needs to be the
+              // smallest of the trace we get as a parameter and of the
+              // trace we got for the receiving graph.
 
-              // We'll need the mz integration parameters from the processing
-              // flow we  get as parameters. Make a copy of them as we'll need
-              // to set the mz smallest and greatest values to them.
+              // We'll need the mz integration parameters from the
+              // processing flow we  get as parameters. Make a copy of
+              // them as we'll need to set the mz smallest and greatest
+              // values to them.
 
               const pappso::MzIntegrationParams *mz_integration_params_p =
                 processing_flow.mostRecentMzIntegrationParams();
 
               if(mz_integration_params_p == nullptr)
                 qFatal(
-                  "Pointer to the returned mz integration parameters cannot be "
+                  "Pointer to the returned mz integration parameters "
+                  "cannot "
+                  "be "
                   "nullptr.");
 
               pappso::MzIntegrationParams copy_mz_integration_params =
                 *processing_flow.mostRecentMzIntegrationParams();
 
-              // Because we are making an integration to a mass spectrum plot
-              // widget, we must have that pointer to mz integration params!
+              // Because we are making an integration to a mass spectrum
+              // plot widget, we must have that pointer to mz integration
+              // params!
 
               for(int iter = 0; iter < dest_plottable_list.size(); ++iter)
                 {
@@ -1365,8 +1440,8 @@ MassSpecTracePlotCompositeWidget::addTrace(
                     static_cast<pappso::BaseTracePlotWidget *>(mp_plotWidget)
                       ->toTrace(static_cast<QCPGraph *>(iter_plottable_p));
 
-                  // Initialize the receiving map trace with the trace we are
-                  // iterating into.
+                  // Initialize the receiving map trace with the trace we
+                  // are iterating into.
                   pappso::MapTrace map_trace(iter_trace);
 
                   double smallest_mz_step =
@@ -1386,13 +1461,15 @@ MassSpecTracePlotCompositeWidget::addTrace(
                   if(m_newTraceHandlingMethod ==
                      NewTraceHandlingMethod::MINUS_COMBINE)
                     {
-                      // qDebug() << "NewTraceHandlingMethod::MINUS_COMBINE";
+                      // qDebug() <<
+                      // "NewTraceHandlingMethod::MINUS_COMBINE";
                       mass_spectrum_minus_combiner.setBins(bins);
                     }
                   else if(m_newTraceHandlingMethod ==
                           NewTraceHandlingMethod::PLUS_COMBINE)
                     {
-                      // qDebug() << "NewTraceHandlingMethod::PLUS_COMBINE";
+                      // qDebug() <<
+                      // "NewTraceHandlingMethod::PLUS_COMBINE";
                       mass_spectrum_plus_combiner.setBins(bins);
                     }
 
@@ -1401,18 +1478,21 @@ MassSpecTracePlotCompositeWidget::addTrace(
                   if(m_newTraceHandlingMethod ==
                      NewTraceHandlingMethod::MINUS_COMBINE)
                     {
-                      // qDebug() << "NewTraceHandlingMethod::MINUS_COMBINE";
+                      // qDebug() <<
+                      // "NewTraceHandlingMethod::MINUS_COMBINE";
                       mass_spectrum_minus_combiner.combine(map_trace, trace);
                     }
                   else if(m_newTraceHandlingMethod ==
                           NewTraceHandlingMethod::PLUS_COMBINE)
                     {
-                      // qDebug() << "NewTraceHandlingMethod::PLUS_COMBINE";
+                      // qDebug() <<
+                      // "NewTraceHandlingMethod::PLUS_COMBINE";
                       mass_spectrum_plus_combiner.combine(map_trace, trace);
                     }
 
-                  // Since the combination is terminated, set the new data to
-                  // the graph (the data are sorted, thus the true below).
+                  // Since the combination is terminated, set the new data
+                  // to the graph (the data are sorted, thus the true
+                  // below).
 
                   // Old version that was deprecated in 5.14.2
                   //
@@ -1427,15 +1507,16 @@ MassSpecTracePlotCompositeWidget::addTrace(
                   QVector<double> value_vector;
 
                   // Apparently, as of 20210928, that bug is fixed.
-                  //#pragma GCC warning "Filippo Rusconi: Please check if the
+                  //#pragma GCC warning "Filippo Rusconi: Please check if
+                  // the
                   // bug was fixed in Qt"
 
                   // Now replace the graph's data. Note that the data are
                   // inherently sorted (true below).
 
-                  // The begin() -- end() ranges constructor did not work as of
-                  // Qt 5.14.2 this day: 20200721 -- and still does not work
-                  // 20211018.
+                  // The begin() -- end() ranges constructor did not work
+                  // as of Qt 5.14.2 this day: 20200721 -- and still does
+                  // not work 20211018.
 
 
                   // key_vector   = QVector(map_trace.xValues().begin(),
@@ -1457,12 +1538,14 @@ MassSpecTracePlotCompositeWidget::addTrace(
             }
         }
       // End of
-      // else of if(!graph_count), that if there are graphs in the plot widget.
+      // else of if(!graph_count), that if there are graphs in the plot
+      // widget.
     }
   // End of if(m_ui.keepTraceCombineNewPushButton->isChecked())
   else if(m_newTraceHandlingMethod == NewTraceHandlingMethod::REPLACE)
     {
-      // qDebug() << "Adding new trace by the replace method: removing the "
+      // qDebug() << "Adding new trace by the replace method: removing the
+      // "
       //"current one(s).";
 
       // Start by erasing all the traces that are selected.
@@ -1491,14 +1574,15 @@ MassSpecTracePlotCompositeWidget::addTrace(
       // At this point we know we need to create a new trace.
 
       // qDebug()
-      //<< "Adding a new trace: in fact we need to create one anew as is.";
+      //<< "Adding a new trace: in fact we need to create one anew as
+      // is.";
 
       plottable_p = static_cast<pappso::BaseTracePlotWidget *>(mp_plotWidget)
                       ->addTrace(trace, local_color);
 
-      // Each time a new trace is added anywhere, it needs to be documented
-      // in the main program window's graph nodes tree! This is what we call
-      // the ms run data plot graph filiation documentation.
+      // Each time a new trace is added anywhere, it needs to be
+      // documented in the main program window's graph nodes tree! This is
+      // what we call the ms run data plot graph filiation documentation.
 
       mp_parentWnd->getProgramWindow()->documentMsRunDataPlottableFiliation(
         ms_run_data_set_csp, plottable_p, parent_plottable_p, this);
@@ -1531,8 +1615,8 @@ MassSpecTracePlotCompositeWidget::addTrace(
         //////// CAUTION ///////
 #endif
 
-      // Map the graph_p to the processing flow that we got to document how
-      // the trace was obtained in the first place.
+      // Map the graph_p to the processing flow that we got to document
+      // how the trace was obtained in the first place.
       m_plottableProcessingFlowMap[plottable_p] = processing_flow;
 
 #if 0
@@ -1599,8 +1683,8 @@ MassSpecTracePlotCompositeWidget::craftAnalysisStanza(
   QString sample_name = ms_run_data_set_csp->getMsRunId()->getSampleName();
 
   // Craft the analysis stanza by copying the m_analysisStanza that was
-  // partially filled-in by the base classes and go on filling-in fields still
-  // marked with "%<char>" format patterns.
+  // partially filled-in by the base classes and go on filling-in fields
+  // still marked with "%<char>" format patterns.
 
   QString orig_stanza = m_analysisStanza;
   QString stanza;
@@ -1649,18 +1733,16 @@ MassSpecTracePlotCompositeWidget::craftAnalysisStanza(
             {
               stanza += QString("\n");
 
-              // Because a newline only works if it is followed by something,
-              // and
-              // if the user wants a termination newline, then we need to
-              // duplicate that new line char if we are at the end of the
-              // string.
+              // Because a newline only works if it is followed by
+              // something, and if the user wants a termination newline,
+              // then we need to duplicate that new line char if we are at
+              // the end of the string.
 
               if(iter == orig_stanza.size() - 1)
                 {
-                  // This is the last character of the line, then, duplicate
-                  // the
-                  // newline so that it actually creates a new line in the
-                  // text.
+                  // This is the last character of the line, then,
+                  // duplicate the newline so that it actually creates a
+                  // new line in the text.
 
                   stanza += QString("\n");
                 }
@@ -1697,8 +1779,8 @@ MassSpecTracePlotCompositeWidget::craftAnalysisStanza(
             }
           if(curChar == 'X')
             {
-              // If the deconvolution was successful, than lastMz is the right
-              // value. Otherwise it is the lastCursorHoveredPoint.
+              // If the deconvolution was successful, than lastMz is the
+              // right value. Otherwise it is the lastCursorHoveredPoint.
 
               if(context.m_lastMz != std::numeric_limits<double>::min())
                 {
@@ -1707,10 +1789,7 @@ MassSpecTracePlotCompositeWidget::craftAnalysisStanza(
               else
                 {
                   stanza += QString("%1").arg(
-                    context.m_lastCursorHoveredPoint.x(),
-                    0,
-                    'g',
-                    6);
+                    context.m_lastCursorHoveredPoint.x(), 0, 'g', 6);
                 }
 
               prevChar = ' ';
@@ -1718,9 +1797,9 @@ MassSpecTracePlotCompositeWidget::craftAnalysisStanza(
             }
           if(curChar == 'Y')
             {
-              // We need to get the value of the intensity for the graph, but
-              // not as an integration to INT, but simply as the y coordinate
-              // of the point at X.
+              // We need to get the value of the intensity for the graph,
+              // but not as an integration to INT, but simply as the y
+              // coordinate of the point at X.
 
               if(context.m_lastMz != std::numeric_limits<double>::min())
                 {
@@ -1738,9 +1817,8 @@ MassSpecTracePlotCompositeWidget::craftAnalysisStanza(
                   stanza += QString("%1").arg(
                     static_cast<pappso::MassSpecTracePlotWidget *>(
                       mp_plotWidget)
-                      ->getYatX(
-                        context.m_lastCursorHoveredPoint.x(),
-                        static_cast<QCPGraph *>(plottable_p)),
+                      ->getYatX(context.m_lastCursorHoveredPoint.x(),
+                                static_cast<QCPGraph *>(plottable_p)),
                     0,
                     'g',
                     6);
@@ -1751,8 +1829,7 @@ MassSpecTracePlotCompositeWidget::craftAnalysisStanza(
             }
           if(curChar == 'x')
             {
-              stanza +=
-                QString("%1").arg(context.m_xDelta, 0, 'g', 6);
+              stanza += QString("%1").arg(context.m_xDelta, 0, 'g', 6);
               prevChar = ' ';
               continue;
             }
@@ -1786,33 +1863,32 @@ MassSpecTracePlotCompositeWidget::craftAnalysisStanza(
             }
           if(curChar == 'b')
             {
-              stanza += QString("%1").arg(
-                context.m_xRegionRangeStart, 0, 'f', 3);
+              stanza +=
+                QString("%1").arg(context.m_xRegionRangeStart, 0, 'f', 3);
 
               prevChar = ' ';
               continue;
             }
           if(curChar == 'e')
             {
-              stanza += QString("%1").arg(
-                context.m_xRegionRangeEnd, 0, 'f', 3);
+              stanza += QString("%1").arg(context.m_xRegionRangeEnd, 0, 'f', 3);
 
               prevChar = ' ';
               continue;
             }
-          // At this point the '%' is not followed by any special character
-          // above, so we skip them both from the text. If the '%' is to be
-          // printed, then it needs to be escaped. We do this because we do not
-          // expect that derived classes will do the format-based field-filling
-          // work later.
+          // At this point the '%' is not followed by any special
+          // character above, so we skip them both from the text. If the
+          // '%' is to be printed, then it needs to be escaped. We do this
+          // because we do not expect that derived classes will do the
+          // format-based field-filling work later.
 
           continue;
         }
       // End of
       // if(prevChar == '%')
 
-      // The character prior this current one was not '%' so we just append
-      // the current character.
+      // The character prior this current one was not '%' so we just
+      // append the current character.
       stanza += curChar;
     }
   // End of
