@@ -37,6 +37,15 @@
 /////////////////////// Qt includes
 #include <QDebug>
 #include <QMainWindow>
+#include <QColor>
+
+
+/////////////////////// libmass includes
+#include <libmass/MassDataCborMassSpectrumHandler.hpp>
+#include <pappsomspp/massspectrum/massspectrum.h>
+#include <pappsomspp/massspectrum/qualifiedmassspectrum.h>
+#include <pappsomspp/msrun/msrundatasettree.h>
+#include <pappsomspp/msrun/msrunid.h>
 
 
 /////////////////////// pappsomspp includes
@@ -46,10 +55,10 @@
 #include "ProgramWindow.hpp"
 #include "MassSpecTracePlotWnd.hpp"
 #include "MassSpecTracePlotCompositeWidget.hpp"
-#include "ColorSelector.hpp"
 #include "../nongui/MassDataIntegratorTask.hpp"
 #include "TaskMonitorCompositeWidget.hpp"
 #include "TaskMonitorWnd.hpp"
+#include "ColorSelector.hpp"
 
 
 namespace msxps
@@ -165,6 +174,9 @@ MassSpecTracePlotWnd::extendMainMenu()
 }
 
 
+// This function does not check if there are widgets that are pinned-down so as
+// to gather new trace data. This function creates a brand new plot composite
+// widget.
 QCPGraph *
 MassSpecTracePlotWnd::addTracePlot(
   const pappso::Trace &trace,
@@ -212,7 +224,7 @@ MassSpecTracePlotWnd::integrateToMz(
   // qDebug() << qSetRealNumberPrecision(10) << "Innermost RT range:"
   //<< "for y axis: " << range_pair.first << "-" << range_pair.second;
 
-  //bool integration_dt = processing_flow.innermostRange("ANY_DT", range_pair);
+  // bool integration_dt = processing_flow.innermostRange("ANY_DT", range_pair);
   // if(integration_dt)
   // qDebug() << qSetRealNumberPrecision(10) << "Innermost DT range:"
   //<< "for y axis: " << range_pair.first << "-" << range_pair.second;
@@ -241,9 +253,9 @@ MassSpecTracePlotWnd::integrateToMz(
   std::size_t qualified_mass_spectra_count = fillInQualifiedMassSpectraVector(
     ms_run_data_set_csp, qualified_mass_spectra_sp, processing_flow);
 
-  //qDebug()
-    //<< "The number of selected mass spectra on the basis of rough RT/DT values:"
-    //<< qualified_mass_spectra_count;
+  // qDebug()
+  //<< "The number of selected mass spectra on the basis of rough RT/DT values:"
+  //<< qualified_mass_spectra_count;
 
   if(!qualified_mass_spectra_count)
     return;
@@ -563,6 +575,144 @@ MassSpecTracePlotWnd::setChargeStateEnvelopePeakSpanPinnedDownWidgets(
 }
 
 
+void
+MassSpecTracePlotWnd::handleReceivedData(const QByteArray &byte_array)
+{
+
+  libmass::MassDataCborMassSpectrumHandler cbor_handler(this);
+
+  if(!cbor_handler.readByteArray(byte_array))
+    {
+      qDebug() << "Failed to read CBOR mass spectrum data.";
+
+      return;
+    }
+
+  pappso::Trace trace = cbor_handler.getTrace();
+  qDebug() << "Received trace of size:" << trace.size();
+
+  QString title               = cbor_handler.getTitle();
+  QByteArray color_byte_array = cbor_handler.getTraceColor();
+
+  // qDebug() << "The data are of type:" << (int)cbor_handler.getMassDataType()
+  //<< "with title:" << title
+  //<< "and trace:" << trace.toString();
+
+  handleReceivedData(
+    title, color_byte_array, std::make_shared<const pappso::Trace>(trace));
+}
+
+
+void
+MassSpecTracePlotWnd::handleReceivedData(const QString &title,
+                                         const QByteArray &color_byte_array,
+                                         pappso::TraceCstSPtr trace_sp)
+{
+
+  // Create a new ms run data set piece by piece.
+
+  pappso::MsRunIdSPtr ms_run_id_sp = std::make_shared<pappso::MsRunId>();
+  ms_run_id_sp->setSampleName(title);
+  ms_run_id_sp->setFileName(title);
+
+  // Create the mass spectrum id instance we'll need later.
+
+  pappso::MassSpectrumId mass_spectrum_id =
+    pappso::MassSpectrumId(ms_run_id_sp);
+
+  // This call creates the ms run data set tree inside the mas run data set.
+  MsRunDataSetSPtr ms_run_data_set_sp =
+    std::make_shared<MsRunDataSet>(nullptr /*parent*/, ms_run_id_sp);
+
+  // Now create the mass spectrum with the trace.
+
+  pappso::MassSpectrumSPtr mass_spectrum_sp =
+    std::make_shared<pappso::MassSpectrum>(*trace_sp);
+
+  // Now create the qualified mass spectrum that we'll add to the ms run data
+  // set.
+
+  pappso::QualifiedMassSpectrumSPtr qualified_mass_spectrum_sp =
+    std::make_shared<pappso::QualifiedMassSpectrum>();
+
+  qualified_mass_spectrum_sp->setMassSpectrumId(mass_spectrum_id);
+  qualified_mass_spectrum_sp->setDtInMilliSeconds(-1);
+  qualified_mass_spectrum_sp->setRtInSeconds(60);
+  qualified_mass_spectrum_sp->setMassSpectrumSPtr(mass_spectrum_sp);
+  qualified_mass_spectrum_sp->setEmptyMassSpectrum(false);
+
+  ms_run_data_set_sp->mapMassSpectrum(qualified_mass_spectrum_sp);
+
+  ProcessingFlow processing_flow;
+  processing_flow.setMsRunDataSetCstSPtr(ms_run_data_set_sp);
+
+  ProcessingStep *new_step_p = new ProcessingStep;
+  new_step_p->setSrcProcessingType(pappso::Axis::x, "SOCKET_MZ");
+  new_step_p->setDestProcessingType(ProcessingType("MZ"));
+  new_step_p->setMzIntegrationParams(
+    ms_run_data_set_sp->craftInitialMzIntegrationParams());
+  processing_flow.push_back(new_step_p);
+
+  // We need to const_cast the step in order to overwrite is
+  // MsFragmentationSpec.
+  MsFragmentationSpec fragmentation_spec =
+    processing_flow.getDefaultMsFragmentationSpec();
+
+  // Set the MS level it to 0 because all the later integrations need to be
+  // capable of involving any MS level. 0 states that MS level matches.
+
+  fragmentation_spec.setMsLevel(0);
+
+  processing_flow.setDefaultMsFragmentationSpec(fragmentation_spec);
+
+  // First thing is create the data plot graph tree, because this is the entry
+  // point to the whole set of data plot graphs : the tree is root into the TIC
+  // chromatogram plot graph because this is where the data exploration starts.
+
+  // At this point, we need to get a color for the plot.
+  // Set true to ask that the color be selected randomly if no color is
+  // available.
+
+  QColor plot_color;
+
+  QByteArray local_color_byte_array = color_byte_array;
+
+  QDataStream stream(&local_color_byte_array, QIODevice::ReadOnly);
+  stream >> plot_color;
+
+  if(!plot_color.isValid())
+    plot_color = libmassgui::ColorSelector::getColor(true);
+
+  // Now we should document the mz integration parameters in the processing flow
+  // that is mapped to the graph in such a way that the default mz integration
+  // parameters that were calculated while loading the ms run from file are
+  // available for the very first integration to mz that might occur.
+
+  // Immediately set the default mz integration params to the local copy of the
+  // processing flow that we'll use later to craft the plot widget.
+
+  processing_flow.setDefaultMzIntegrationParams(
+    ms_run_data_set_sp->craftInitialMzIntegrationParams());
+
+  // qDebug().noquote()
+  //<< "Default mz integration parameters:"
+  //<< processing_flow.getDefaultMzIntegrationParams().toString();
+
+  // Let's see the usage count of the MsRunDataSetCstSPtr.
+  //	qDebug() << "Usage count:" << ms_run_data_set_csp.use_count();
+
+  // And now that these params are documented, create the graph! Note the
+  // nullptr parameter that shows that there is no parent graph here.
+
+  // qDebug() << "going to call newTrace()";
+
+  newTrace(*mass_spectrum_sp,
+           ms_run_data_set_sp,
+           processing_flow,
+           plot_color,
+           nullptr);
+}
+
 } // namespace minexpert
 
 
