@@ -38,6 +38,8 @@
 #include <QSettings>
 #include <QDebug>
 #include <QMainWindow>
+#include <pappsomspp/processing/combiners/mzintegrationparams.h>
+#include <pappsomspp/trace/datapoint.h>
 
 
 /////////////////////// pappsomspp includes
@@ -222,7 +224,7 @@ TicXicChromTracePlotWnd::finishedIntegratingToInitialTicChromatogram(
   // At this point, we need to get a color for the plot.
   // Set true to ask that the color be selected randomly if no color is
   // available.
-  QColor plot_color = ColorSelector::getColor(true);
+  QColor plot_color = libmassgui::ColorSelector::getColor(true);
 
   // Now we should document the mz integration parameters in the processing flow
   // that is mapped to the graph in such a way that the default mz integration
